{{/*
    Get the correct IAM role. 
    If existing_roles is set, takes value from the GC values overrides
    If appIamRole.serviceRole is set, generate a rolename to use already existing role created using core-infrastruture repo.
    For partial env also set global.partialIamRole: true to use the partial role created via core infrastructure.
    else generate the rolename using releaseName and alias.
*/}}

{{- define "app-utils._awsIamRole" -}}
{{- if .Values.existing_role -}}
  {{- .Values.existing_role -}}
{{- else -}}
  {{- required "global.awsIamRolePrefix must be specified for this chart" .Values.global.awsIamRolePrefix -}}
  /mcs2-app-
    {{- if .Values.appIamRole.serviceRole -}}
        {{- if .Values.global.partialIamRole -}}
          partial-
        {{- else -}}
          {{- required "global.env is a required value. run `helm with --set global.env=$USER` for developers" .Values.global.env -}}-
        {{- end -}}
      {{- required "appIamRole.serviceRole must be specified for this chart" .Values.appIamRole.serviceRole -}}-role
    {{- else -}}
      {{- required "global.env is a required value. run `helm with --set global.env=$USER` for developers" .Values.global.env -}}-
      {{- required "appIamRole.releaseName must be specified for this chart" .Values.appIamRole.releaseName -}}-
      {{- required "appIamRole.alias must be specified for this chart" .Values.appIamRole.alias }}
    {{- end -}}
{{- end -}}
{{- end -}}


{{/*
    When deployed on AWS, this will emit the annotations necessary to wire up kube2iam roles
    Example usage:
        {{- include "app-utils.conditionalAWSAnnotations" . | nindent 8 }}

    TODO may want to DRY this out with the utils-lib chart

    TODO this will likely be refactored and may change the semantics for downstream consumers...
*/}}
{{- define "app-utils.conditionalAWSAnnotations" -}}
{{- if .Values.global.awsDeployment -}}
iam.amazonaws.com/role: {{ include "app-utils._awsIamRole" . }}
{{- end -}}
{{- end -}}

{{/*
    When deployed on AWS, this will emit the necessary volumeMount element definition
    to mount the RDS CA
    Example usage:
    volumeMounts:
    {{- include "app-utils.rds-ca-volumeMount" . | nindent 10 }}
*/}}
{{- define "app-utils.rds-ca-volumeMount" -}}
{{- if .Values.global.awsDeployment -}}
- name: rds-combined-ca-bundle
  mountPath: "/app/certs/rds-combined-ca-bundle.pem"
  subPath: "rds-combined-ca-bundle.pem"
  readOnly: true
{{- end -}}
{{- end -}}

{{/*
    When deployed on AWS, this will emit the necessary volume element definition to
    mount the RDS CA
    Example usage:
        volumes:
        {{- include "app-utils.rds-ca-volume" . | nindent 8 }}
*/}}
{{- define "app-utils.rds-ca-volume" -}}
{{- if .Values.global.awsDeployment -}}
- name: rds-combined-ca-bundle
  configMap:
    name: rds-combined-ca-bundle
    items:
    - key: rds-combined-ca-bundle.pem
      path: rds-combined-ca-bundle.pem
{{- end -}}
{{- end -}}

{{/*
    Creates the environment variables for using RDS.
    Requires aurora-0.1.37 or greater.

    Example usage:
        In deployments.yaml:
            env:
            {{- include "app-utils.rds-env" (merge (dict "awsDeployment" .Values.global.awsDeployment) .Values.infra.rds) | nindent 12 }}

        In values.yaml:
            infra:
                rds:
                    releaseName: <infra-chart-name>
                    alias: <infra-alias>
                    internalNameOverride: <same as the value set in infra chart> #optional
*/}}
{{- define "app-utils.rds-env" -}}
- name: RDS_USER
  valueFrom:
    secretKeyRef:
      name: {{ include "app-utils.infraNamingPrefix" . }}-pg-user
      key: user
- name: RDS_PASSWORD
  valueFrom:
    secretKeyRef:
      name: {{ include "app-utils.infraNamingPrefix" . }}-pg-pass
      key: password
- name: RDS_WRITER_HOST
  valueFrom:
    configMapKeyRef:
      name: {{ include "app-utils.infraNamingPrefix" . }}-endpoint
      key: endpoint
- name: RDS_READER_HOST
  valueFrom:
    configMapKeyRef:
      name: {{ include "app-utils.infraNamingPrefix" . }}-endpoint
      key: readerEndpoint
- name: RDS_DB
  valueFrom:
    configMapKeyRef:
      name: {{ include "app-utils.outputConfigMap" . }}
      key: databaseName
- name: RDS_PORT
  valueFrom:
    configMapKeyRef:
      name: {{ include "app-utils.outputConfigMap" . }}
      key: port
{{ if .awsDeployment }}
- name: RDS_SSLMODE
  value: "verify-ca"
- name: RDS_SSLROOTCERT
  value: "/app/certs/rds-combined-ca-bundle.pem"
{{ else }}
- name: RDS_SSLMODE
  value: "disable"
{{ end }}
{{- end -}}
