{{- define "app-utils.var_internalNamingPrefix" -}}
{{ .releaseName }}-{{ .alias }}
{{- end -}}

{{/*
    Generates the naming prefix used in the infra charts
    inputs scope must not be .
    inputs scope must be a dict that contains .releaseName and .alias
    optionally .internalNameOverride. The value for .internalNameOverride if set should
    be equal to the one set in the infra chart.
    Please Note: infraNamingPrefix is the same as namingPrefix in utils-lib
*/}}
{{- define "app-utils.infraNamingPrefix" -}}
{{- if .internalNameOverride -}}
{{- .internalNameOverride -}}
{{- else -}}
{{- include "app-utils.var_internalNamingPrefix" . -}}
{{- end -}}
{{- end -}}

{{/*
    Generates the name of the output config map
    inputs scope must not be .
    inputs scope must be a dict that contains .releaseName and .alias
    optionally .internalNameOverride. The value for .internalNameOverride if set should
    be equal to the one set in the infra chart.
*/}}
{{- define "app-utils.outputConfigMap" -}}
{{- include "app-utils.infraNamingPrefix" . -}}-outputs
{{- end -}}

{{/*
    Generates the name of the arn config map
    inputs scope must not be .
    inputs scope must be a dict that contains .releaseName and .alias
    optionally .internalNameOverride. The value for .internalNameOverride if set should
    be equal to the one set in the infra chart.
*/}}
{{- define "app-utils.arnConfigMap" -}}
{{- include "app-utils.infraNamingPrefix" . -}}-arn
{{- end -}}

{{/*
    Generates the host used for routing to this environment
*/}}
{{- define "app-utils.externalIngressHostName" -}}
{{ default "app" .Values.global.subDomain }}.{{- required "global.host is a required value. Define it in your env definitions yaml." .Values.global.host }}
{{- end -}}

{{- define "app-utils.CSRIngressHostName" -}}
{{ default "app" .Values.global.subDomain }}-csr.{{- required "global.host is a required value. Define it in your env definitions yaml." .Values.global.host }}
{{- end -}}

{{- define "app-utils.deviceIngressHostName" -}}
{{ default "app" .Values.global.subDomain }}-device.{{- required "global.host is a required value. Define it in your env definitions yaml." .Values.global.host }}
{{- end -}}

{{- define "app-utils.APIIngressHostName" -}}
{{ default "app" .Values.global.subDomain }}-api.{{- required "global.host is a required value. Define it in your env definitions yaml." .Values.global.host }}
{{- end -}}

{{- define "app-utils.cspIngressHostName" -}}
{{ default "app" .Values.global.subDomain }}-csp.{{- required "global.host is a required value. Define it in your env definitions yaml." .Values.global.host }}
{{- end -}}

{{- define "app-utils.internalIngressHostName" -}}
{{ default "app" .Values.global.subDomain }}-internal.{{- required "global.host is a required value. Define it in your env definitions yaml." .Values.global.host }}
{{- end -}}

{{- define "app-utils.grpcInternalIngressHostName" -}}
{{ default "app" .Values.global.subDomain }}-grpc-internal.{{- required "global.host is a required value. Define it in your env definitions yaml." .Values.global.host }}
{{- end -}}

{{/*
    TLS Config for all the hosts
*/}}
{{- define "app-utils.externalIngressTls" -}}
{{- if and .Values.global.extIngressType .Values.global.sslCert -}}
{{- if or (eq .Values.global.extIngressType "vdp-nginx-l4-ext") (eq .Values.global.extIngressType "vdp-nginx-l4-vmware") (eq .Values.global.extIngressType "nginx-l4-ext") (eq .Values.global.extIngressType "vdp-nginx-l4-nlb-ext") -}}
tls:
- hosts:
    - {{ include "app-utils.externalIngressHostName" . }}
  secretName: {{ .Values.global.sslCert }}
{{- end -}}
{{- end -}}
{{- end -}}

{{- define "app-utils.CSRIngressTls" -}}
{{- if and .Values.global.csrIngressType .Values.global.sslCert -}}
{{- if or (eq .Values.global.csrIngressType "nginx-l4-int") (eq .Values.global.csrIngressType "vdp-nginx-l4-vmware") (eq .Values.global.csrIngressType "vdp-nginx-l4-ext") (eq .Values.global.csrIngressType "nginx-l4-ext") (eq .Values.global.csrIngressType "vdp-nginx-l4-nlb-ext") -}}
tls:
- hosts:
    - {{ include "app-utils.CSRIngressHostName" . }}
  secretName: {{ .Values.global.sslCert }}
{{- end -}}
{{- end -}}
{{- end -}}

{{- define "app-utils.deviceIngressTls" -}}
{{- if and .Values.global.deviceIngressType .Values.global.sslCert -}}
{{- if or (eq .Values.global.deviceIngressType "vdp-nginx-l4-ext") (eq .Values.global.deviceIngressType "vdp-nginx-l4-vmware") (eq .Values.global.deviceIngressType "nginx-l4-ext") (eq .Values.global.deviceIngressType "vdp-nginx-l4-nlb-ext") -}}
tls:
- hosts:
    - {{ include "app-utils.deviceIngressHostName" . }}
  secretName: {{ .Values.global.sslCert }}
{{- end -}}
{{- end -}}
{{- end -}}

{{- define "app-utils.APIIngressTls" -}}
{{- if and .Values.global.apiIngressType .Values.global.sslCert -}}
{{- if or (eq .Values.global.apiIngressType "vdp-nginx-l4-ext") (eq .Values.global.apiIngressType "vdp-nginx-l4-vmware") (eq .Values.global.apiIngressType "nginx-l4-ext") (eq .Values.global.apiIngressType "vdp-nginx-l4-nlb-ext") -}}
tls:
- hosts:
    - {{ include "app-utils.APIIngressHostName" . }}
  secretName: {{ .Values.global.sslCert }}
{{- end -}}
{{- end -}}
{{- end -}}

{{- define "app-utils.internalIngressTls" -}}
{{- if and .Values.global.intIngressType .Values.global.sslCert -}}
tls:
- hosts:
    - {{ include "app-utils.internalIngressHostName" . }}
  secretName: {{ .Values.global.sslCert }}
{{- end -}}
{{- end -}}