{{- /*
  ---------------------------------------------------
  app-utils.destinationRule Template
  This template is used for generating a DestinationRule resource for Istio.
  ---------------------------------------------------
*/ -}}

{{- /* Check if `destinationRule` and its required child `trafficPolicy` are provided. */ -}}
{{- define "app-utils.destinationRule" -}}
{{- if .Values.destinationRule -}}
  {{- if not .Values.destinationRule.trafficPolicy -}}
    {{- required "If destinationRule is provided, destinationRule.trafficPolicy is a required value." .Values.destinationRule.trafficPolicy -}}-
  {{- end -}}
{{- end -}}

{{- /* Set the default values for the destination rule. */ -}}
{{- $defaultDestinationRule := dict
    "trafficPolicy" (dict
        "loadBalancer" (dict
            "simple" "ROUND_ROBIN"
            "localityLbSetting" (dict "enabled" "true")
        )
        "outlierDetection" (dict
            "baseEjectionTime" "10s"
            "consecutive5xxErrors" 0
            "interval" "10s"
            "maxEjectionPercent" 0
        )
    )
-}}

{{- /* Create a deep copy of the user's destination rule, or default to an empty dictionary if none is provided. */ -}}
{{- $userDestinationRule := .Values.destinationRule | default dict  | deepCopy -}}

{{- /* Create a deep copy of the user's destination rule, or default to an empty dictionary if none is provided. */ -}}
{{- $mergedDestinationRule := merge $userDestinationRule $defaultDestinationRule -}}

{{- /* Convert localityLbSetting.enabled from string to boolean */ -}}
{{- $localityLbSetting := get $mergedDestinationRule.trafficPolicy.loadBalancer "localityLbSetting" -}}
{{- $enabled := eq ($localityLbSetting.enabled | toString | lower) "true" -}}
{{- $_ := set $localityLbSetting "enabled" $enabled -}}

{{- /* Start generating the actual DestinationRule YAML definition. */ -}}
apiVersion: networking.istio.io/v1beta1
kind: DestinationRule
metadata:
  name: {{ include "app-utils.fullname" . }}-dest-rule-80
  namespace: {{ .Release.Namespace }}
  labels:
    {{- include "app-utils.labels" . | nindent 4 }}
  annotations:
    {{- include "app-utils.annotations" . | nindent 4 }}
spec:
  host: {{ include "app-utils.fullname" . }}.{{ .Release.Namespace }}.svc.cluster.local
  {{- /* Convert the merged destination rule into YAML format and indent it by 2 spaces. */ -}}
  {{- $mergedDestinationRule | toYaml | nindent 2 }}
{{- end }}