{{/* CSP Auth */}}

{{/*
    Annotations for External Ingress resources for externally authenticated requests
*/}}
{{- define "app-utils.externalIngressAuthAnnotations" -}}
nginx.ingress.kubernetes.io/auth-url: {{ include "app-utils.authEndpoint" . }}
nginx.ingress.kubernetes.io/auth-response-headers: X-Request-Context, X-User-Context, Authorization
{{- end -}}

{{- define "app-utils.externalIngressNonAuthAnnotations" -}}
kubernetes.io/ingress.class: {{ .Values.global.extIngressType | default "vdp-nginx-l7-ext" }}
nginx.ingress.kubernetes.io/configuration-snippet: |
  proxy_set_header X-Request-Context "";
  proxy_set_header X-User-Context "";
  proxy_hide_header X-Request-Context;
  proxy_hide_header X-User-Context;
  add_header Content-Security-Policy "frame-ancestors 'self';" always;
  add_header Strict-Transport-Security "max-age=31536000; includeSubDomains" always;
  add_header Referrer-Policy "origin" always;
{{- end -}}

{{- define "app-utils.externalIngressAnnotations" -}}
{{ include "app-utils.externalIngressAuthAnnotations" . }}
{{ include "app-utils.externalIngressNonAuthAnnotations" . }}
{{- end -}}

{{/*
    Annotations for External Ingress resources for externally authenticated requests using legacy auth
*/}}
{{- define "app-utils.externalLegacyAPIIngressAuthAnnotations" -}}
nginx.ingress.kubernetes.io/auth-url: {{ include "app-utils.legacyAPIAuthEndpoint" . }}
nginx.ingress.kubernetes.io/auth-response-headers: X-Auth-Token
{{- end -}}

{{- define "app-utils.externalLegacyAPIIngressNonAuthAnnotations" -}}
kubernetes.io/ingress.class: {{ .Values.global.extIngressType | default "vdp-nginx-l7-ext" }}
nginx.ingress.kubernetes.io/configuration-snippet: |
  add_header Content-Security-Policy "frame-ancestors 'self';" always;
  add_header Strict-Transport-Security "max-age=31536000; includeSubDomains" always;
  add_header Referrer-Policy "origin" always;
{{- end -}}

{{- define "app-utils.externalLegacyAPIIngressAnnotations" -}}
{{ include "app-utils.externalLegacyAPIIngressAuthAnnotations" . }}
{{ include "app-utils.externalLegacyAPIIngressNonAuthAnnotations" . }}
{{- end -}}

{{/*
    Annotations for API Ingress resources for requests that need to be authenticated
*/}}
{{- define "app-utils.externalAPIIngressAuthAnnotations" -}}
nginx.ingress.kubernetes.io/auth-url: {{ include "app-utils.authEndpoint" . }}
nginx.ingress.kubernetes.io/auth-response-headers: X-Request-Context, X-User-Context, Authorization
{{- end -}}

{{- define "app-utils.externalAPIIngressNonAuthAnnotations" -}}
kubernetes.io/ingress.class: {{ .Values.global.apiIngressType | default "vdp-nginx-l7-ext" }}
nginx.ingress.kubernetes.io/configuration-snippet: |
  proxy_set_header X-Request-Context "";
  proxy_set_header X-User-Context "";
  proxy_hide_header X-Request-Context;
  proxy_hide_header X-User-Context;
  add_header Content-Security-Policy "frame-ancestors 'self';" always;
  add_header Strict-Transport-Security "max-age=31536000; includeSubDomains" always;
  add_header Referrer-Policy "origin" always;
{{- end -}}

{{- define "app-utils.externalAPIIngressAnnotations" -}}
{{ include "app-utils.externalAPIIngressAuthAnnotations" . }}
{{ include "app-utils.externalAPIIngressNonAuthAnnotations" . }}
{{- end -}}

{{/*
    Annotations for CSR Ingress resources for requests that need to be authenticated
*/}}
{{- define "app-utils.externalCSRIngressAuthAnnotations" -}}
nginx.ingress.kubernetes.io/auth-url: {{ include "app-utils.authEndpoint" . }}
nginx.ingress.kubernetes.io/auth-response-headers: X-Request-Context, X-User-Context, Authorization
{{- end -}}

{{- define "app-utils.externalCSRIngressNonAuthAnnotations" -}}
kubernetes.io/ingress.class: {{ .Values.global.csrIngressType | default "vdp-nginx-l4-vmware" }}
nginx.ingress.kubernetes.io/configuration-snippet: |
  proxy_set_header X-Request-Context "";
  proxy_set_header X-User-Context "";
  proxy_hide_header X-Request-Context;
  proxy_hide_header X-User-Context;
  add_header Content-Security-Policy "frame-ancestors 'self';" always;
  add_header Strict-Transport-Security "max-age=31536000; includeSubDomains" always;
  add_header Referrer-Policy "origin" always;
{{- end -}}

{{- define "app-utils.externalCSRIngressAnnotations" -}}
{{ include "app-utils.externalCSRIngressAuthAnnotations" . }}
{{ include "app-utils.externalCSRIngressNonAuthAnnotations" . }}
{{- end -}}

{{/*
    Annotations for Ingress resources for internal requests with authentication
*/}}
{{- define "app-utils.internalAuthenticatedIngressAuthAnnotations" -}}
nginx.ingress.kubernetes.io/auth-url: {{ include "app-utils.authInternalEndpoint" . }}
nginx.ingress.kubernetes.io/auth-response-headers: X-Request-Context, X-User-Context, Authorization
nginx.ingress.kubernetes.io/configuration-snippet: |
  proxy_hide_header X-Request-Context;
  proxy_hide_header X-User-Context;
{{- end -}}

{{- define "app-utils.internalAuthenticatedIngressNonAuthAnnotations" -}}
kubernetes.io/ingress.class: {{ .Values.global.intIngressType | default "nginx-l4-int" }}
nginx.ingress.kubernetes.io/ssl-redirect: 'false'
{{- end -}}

{{- define "app-utils.internalAuthenticatedIngress" -}}
{{ include "app-utils.internalAuthenticatedIngressAuthAnnotations" . }}
{{ include "app-utils.internalAuthenticatedIngressNonAuthAnnotations" . }}
{{- end -}}
